pub struct SimilaritySessionCompletion { /* private fields */ }Expand description
Stop requests, progress, and timing for a session run.
Implementations
Sourceimpl SimilaritySessionCompletion
impl SimilaritySessionCompletion
Sourcepub fn new() -> Ref<Self>
pub fn new() -> Ref<Self>
Creates a new completion state, typically only done when calling into providers and resolvers directly instead of from a session.
pub unsafe fn from_raw(handle: *mut BNSimilaritySessionCompletion) -> Self
pub unsafe fn ref_from_raw( handle: *mut BNSimilaritySessionCompletion, ) -> Ref<Self>
Sourcepub fn is_finished(&self) -> bool
pub fn is_finished(&self) -> bool
Returns whether the session run has finished.
Sourcepub fn progress(&self, query: SimilaritySessionCompletionQuery) -> f64
pub fn progress(&self, query: SimilaritySessionCompletionQuery) -> f64
Returns progress for the selected part of the run from 0.0 through 1.0.
Sourcepub fn request_stop(&self)
pub fn request_stop(&self)
Asks the run to stop.
Sourcepub fn is_stop_requested(&self) -> bool
pub fn is_stop_requested(&self) -> bool
Returns whether a stop has been requested.
Sourcepub fn set_progress(
&self,
query: SimilaritySessionCompletionQuery,
progress: f64,
)
pub fn set_progress( &self, query: SimilaritySessionCompletionQuery, progress: f64, )
Increases progress for a node and one provider or resolver. Progress cannot decrease.
NOTE: Only call this from the provider or resolver selected by the query.
Sourcepub fn timing(&self, query: SimilaritySessionCompletionQuery) -> Duration
pub fn timing(&self, query: SimilaritySessionCompletionQuery) -> Duration
Returns timing for the selected part of the run.